#!/bin/sh

# Common functions used by other scripts
# $Header: /usr/local/cvsroot/panacache/admin/common/common.sh,v 1.3 2016/03/02 08:10:02 wanglin Exp $
# ChangeLogs:
# (1)2004/11/11: softmic created the file
#

. /etc/cache.conf

[ "${IXCACHEPATH}" = "" ] && IXCACHEPATH="/usr/ixcache"
PGPATH="${IXCACHEPATH}"
PGBIN=${IXCACHEPATH}/bin
ICSEYE=${IXCACHEPATH}/bin/icseye
EVENTFILE=${IXCACHEPATH}/log/pending_events
PGETC=${IXCACHEPATH}/etc
DATAPATH=${PGPATH}/log

#If PGETC is not exist, create it.
[ ! -d ${PGETC} ] && mkdir ${PGETC}

if [ -f ${PGPATH}/etc/ixcache.inf ]; then
	. ${PGPATH}/etc/ixcache.inf
fi

if [ -f ${PGETC}/sysname.conf ]; then
	. ${PGETC}/sysname.conf
fi

paging() {
	total=0
	lines=0

	[ "X$1" != "X" ] && total=$1
	[ "X$2" != "X" ] && lines=$2

	echo $total $lines | awk '
		function paging(total, lines)
		{
			if (lines == 0) {
				printf("%d", 0);
				return;
			}
			pages = total / lines;
			remai = total % lines;
			if (remai && remai < lines)
				pages ++;
			printf("%d", pages);
		}
		{
			paging($1, $2);
		}
	'
}

scale_convert()
{
	bytes=0
	based=0
	float=0

	[ "X$1" != "X" ] && bytes=$1
	[ "X$2" != "X" ] && based=$2
	[ "X$3" != "X" ] && float=$3

	echo $bytes $based $float | awk '
		function scale_convert(bytes, based, float)
		{
			scales[0] = "";
			scales[1] = "K";
			scales[2] = "M";
			scales[3] = "G";
			scales[4] = "T";

			for (i = based; bytes >= 1024 && i < 5; i ++)
				bytes /= 1024;
			if (i > 4)
				i = 4;

			if (float)
				printf("%.2f%s", bytes, scales[i]);
			else
				printf("%d%s",   bytes, scales[i]);
		}
		{
			scale_convert($1, $2, $3);
		}
	'
}

afm_dialog_msg()
{
    echo "<script language=javascript>"
    echo "alert(\"$1\");"
    echo "</script>"
}

cgi_print_mod_header()
{
	local width

	width=$2
	[ "${width}" = "" ] && width=700
	echo "<div id=\"list1\" style=\"width:${width};height:27\"><UL>"

	for capurl in ${MOD_TAB_LIST}
	do
		cap=`echo ${capurl} | cut -d'#' -f1`
		url=`echo ${capurl} | cut -d'#' -f2`
		if [ "${cap}" = "$1" ]; then
			echo "<li class=current><a href=\"${url}\">${cap}</a></li>"
		else
			echo "<li><a href=\"${url}\">${cap}</a></li>"
		fi
	done
	echo "</UL></DIV>"
}

# redirect current page to the designated page
# @param arg1 time to wait
# @param arg2 url of the designated page
# @return 
afm_load_page()
{
    echo "<META HTTP-EQUIV=REFRESH CONTENT=\"$1;URL=$2\">"
}

# to see if arg1 is digit number
# @param arg1
# @return 1(yes), 0(no)
afm_isdigit()
{
	local ret=""

	ret=`echo $1 | sed -e "s/[0-9]//g"`
	[ "${ret}" = "" -o "${ret}" = "-" ] && return 1
	return 0
}

# @param arg1 the number
# @param arg2 begin number
# @param arg3 end number
# @return 1(yes) 0(no)
afm_isbetween()
{
	local ret=""

	ret=`echo $1 | sed -e "s/[0-9]//g"`
	[ "${ret}" != "" -a "${ret}" != "-" ] && return 0
	
	[ $1 -ge $2 -a $1 -le $3 ] && return 1
	return 0
}

# to see if arg1 is an IP address
# @param arg1
# @return 1(yes), 0(no)
afm_isipaddr()
{
	local v=""

	v=`echo $1 | cut -d'.' -f1`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f2`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f3`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f4`
	afm_isbetween "$v" 0 255
	[ "$?" = "0" ] && return 0

	v=`echo $1 | cut -d'.' -f5`
	[ "$v" != "" ] && return 0

	return 1 
}

cgi_show_title()
{
	curtime=`date +%s`
	boottime=`sysctl -n kern.boottime | cut -d',' -f1 | cut -d'=' -f2`
	boottime=$((${curtime} - ${boottime}))
	bootday=$((${boottime} / 86400))
	dayhour=$((${bootday} * 24))
	boothour=$((${boottime} / 3600))
	boothour=$((${boothour} - ${dayhour}))
	bootsec=$((${boottime} % 3600))
	bootmin=$((${bootsec} / 60))
	bootsec=$((${boottime} % 60))

	width="$2"
	[ "${width}" = "" ] && width=700

	echo "<table class=title width=${width}>"
	echo "<tr><td><b>$1</b></td><td style=\"font-size:12px;color:#185A73\" align=right width=*>${bootday}${boothour}Сʱ${bootmin}${bootsec}"
	if [ -f ${DATAPATH}/ixcache.core ]; then
		echo "(${SYSNAME}crash)"
	else
		if [ "${SYSNAME}" = "" ]; then
			echo "(${PANABIT_USER})"
		else
			echo "<b style=\"color:#ff0000\">[&nbsp;${SYSNAME}&nbsp]</b>"
		fi
	fi
	echo "</td></tr></table>"
}

cgi_show_iptype()
{
        local anyselect=""
        local netselect=""
        local rngselect=""

        case "$1" in
        "any")
                anyselect="selected"
                ;;
        "net")
                netselect="selected"
                ;;
        "iprange")
                rngselect="selected"
                ;;
        esac

        echo "<option value=\"any\" ${anyselect}>ַ</option>"
        echo "<option value=\"net\" ${netselect}>xxx.xxx.xxx.xxx/nn</option>"
        echo "<option value=\"range\" ${rngselect}>n.n.n.n-m.m.m.m</option>"

        if [ "${tblexists}" != "" ]; then
                if [ "$1" = "table" ]; then
                        echo "<option value=\"table\" selected>IPȺ</option>"
                else
                        echo "<option value=\"table\">IPȺ</option>"
                fi
        fi
}

operator_check()
{
	local url=$1
	local user=$2

	[ "${user}" = "" ] && user=${ADMIN_NAME}
	if [ "${PANABIT_USER}" != "${ADMIN_NAME}" -a "${PANABIT_USER}" != "${user}" ]; then
		afm_dialog_msg "Ȩ޲!"
		afm_load_page 0 "${url}"
		exit 0
	fi
}

cgi_show_app_info()
{
	local appid="$1"
	local width=$2
	local nameval

	wid8=$((${width} / 8))
	wid4=$((${width} / 4))	

	output=`${FLOWEYE} app get ${CGI_appid}`
	if [ "${output}" != "" ]; then
		for nameval in ${output}; do
        		eval "${nameval}"
		done
	fi

	echo "<table width=${width} border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr height=22>
    <td width=${wid8} align=center></td>
    <td width=${wid8} align=center>ڵ</td>
    <td width=${wid4} align=center>(/)</td>
    <td width=${wid4} align=center>(/)</td>
    <td width=* align=center>(/)</td>
</tr>
<tr id=row1 height=22>
        <td align=right>${flowcnt}</td>
        <td align=right>${nodecnt}</td>
        <td align=right>${upbytes}/${downbytes}</td>
        <td align=right>${upbps}/${downbps}</td>
        <td align=right>${nat_upbps}/${nat_downbps}</td>
</tr>
</table>"
}

cgi_show_ipobj_info()
{
	echo "<table width=613 border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr>
        <td width=90 align=center><b>TTL()</b></td>
        <td width=100 align=center><b>ʱ()</b></td>
        <td width=100 align=center><b></b></td>
        <td width=100 align=center><b></b></td>
        <td width=100 align=center><b>bps</b></td>
        <td width=* align=center><b>bps</b></td>
</tr>
<tr id=row1>
        <td align=right>${ttl}</td>
        <td align=right>${life}</td>
        <td align=right>${outbytes}</td>
        <td align=right>${inbytes}</td>
        <td align=right>${bpsout}</td>
        <td align=right>${bpsin}</td>
</tr>
</table>

<table width=613 border=0 cellspacing=1 cellpadding=1>
<tr id=tblhdr>
        <td width=193 align=center><b>MACַ</b></td>
        <td width=100 align=center><b></b></td>
        <td width=100 align=center><b></b></td>
        <td width=100 align=center><b>û</b></td>
        <td width=* align=center><b>ƶն</b></td>
</tr>
<tr id=row1>
        <td align=center>${mac}</td>
        <td align=right>${flowcnt}</td>
        <td align=right>${accountcnt}</td>
        <td align=right>${natipcnt}/${ipidcnt}</td>"

	if [ "${mstcnt}" = "" -o "${mstcnt}" = "0" ]; then
        	echo "<td align=right></td>"
	else
		echo "<td align=right><a style=\"color:#ff0000\"><b></b></a></td>"
	fi

	echo "</tr></table>"
}

WEB_LOGGER()
{
	local logfile
	local curtime

	localfile="${DATAPATH}/web_`date +%Y.%m.%d`.log"
	curtime=`date +%Y.%m.%d/%H:%M:%S`
	echo "${curtime} ${REMOTE_ADDR} ${PANABIT_USER} $1 $2" >> ${localfile}
}

TMPPATH=${PGPATH}/admin/tmp
MAXPRI=6
ADMIN_NAME="admin"
[ "${TOPSEC}" != "" ] && ADMIN_NAME="superman"

#
# Show CGI header
#
echo "<html xmlns:v=\"urn:schemas-microsoft-com:vml\" xmlns:o=\"urn:schemas-microsoft-com:office:office\">
<head><title></title>
<link href=\"/img/p2p.css\" type=\"text/css\" rel=\"stylesheet\">
<meta http-equiv=\"Content-Type\" content=\"text/html; charset=gb2312\">
<META HTTP-EQUIV=\"Pragma\" CONTENT=\"no-cache\">
<META HTTP-EQUIV=\"Cache-Control\" content=\"no-cache\">
</head>"
